@@ -426,6 +426,18 @@ def ellipse_calculation(ellipse_pos, start, end, start_dim, end_dim, minor_axis)
     abs_minor_axis = abs(minor_axis)
     abs_half_minor_axis = abs(0.5 * minor_axis)
 
+    arcsin_argument = end_dim / (2 * abs_half_minor_axis)
+    if arcsin_argument >= 1 or arcsin_argument <= -1:
+        print("arcsin error, end and half axis")
+        print("end", end_dim, "minor_axis", minor_axis)
+        print("arcsin_argument", arcsin_argument)
+
+    arcsin_argument = start_dim / (2 * abs_half_minor_axis)
+    if arcsin_argument >= 1 or arcsin_argument <= -1:
+        print("arcsin error, end and half axis")
+        print("start", start_dim, "minor_axis", minor_axis)
+        print("arcsin_argument", arcsin_argument)
+
     element_length = end - start
     if minor_axis > 0:
         tmp_k = np.cos(np.arcsin(end_dim / (2 * abs_half_minor_axis))) / np.cos(
