@@ -3,6 +3,7 @@ import os
 import dill
 import yaml
 
+from _version import __version__
 from guide_bot.parameters import instrument_parameters as ipars
 from guide_bot.parameters import instrument_parameter_container as ipars_container
 import guide_bot.requirements.requirement_parameters as rpars
@@ -25,7 +26,7 @@ class Guide:
     opening dimensions by the transfer_end_specifications method. The Guide
     can add code to a McStasScript instrument object using the
     add_to_instrument method, this is done from sample to source, and the
-    previous start dimensions are transfered to the next module in each step.
+    previous start dimensions are transferred to the next module in each step.
     """
     def __init__(self, name=None):
         """
@@ -532,7 +533,7 @@ class Project:
             self.settings["minfunc"] = 1E-8
 
         if "logfile" not in self.settings:
-            self.settings["logfile"] = False
+            self.settings["logfile"] = True
 
         self.settings["optimized_monitor"] = "fom.dat"
         self.settings["foldername"] = "optimization_data"
@@ -600,27 +601,33 @@ class Project:
 
         # Write overview file
         moderator = {"moderator_name": self.moderator.get_name(),
+                     "moderator_fixed": scan.moderator_parameters.get_fixed_dict(),
                      "moderator_scan": scan.moderator_parameters.get_scan_dict(),
-                     "moderator_units": scan.moderator_parameters.get_unit_dict(only_scanned=True)}
+                     "moderator_units": scan.moderator_parameters.get_unit_dict()}
 
         sample = {"sample_name": type(self.sample).__name__,
+                  "sample_fixed": scan.sample_parameters.get_fixed_dict(),
                   "sample_scan": scan.sample_parameters.get_scan_dict(),
-                  "sample_units": scan.sample_parameters.get_unit_dict(only_scanned=True)}
+                  "sample_units": scan.sample_parameters.get_unit_dict()}
 
-        analysis_moderators = []
+        analysis_moderators = {}
         for mod in self.analysis_moderators:
-            analysis_moderators.append(mod.get_name())
+            mod_name = mod.get_name()
+            analysis_moderators[mod_name] = {}
+            analysis_moderators[mod_name]["parameters"] = mod.parameters.get_fixed_dict()
+            analysis_moderators[mod_name]["units"] = mod.parameters.get_unit_dict()
 
         scan_states = []
         scan.reset_configuration()
         while scan.next_state():
-            state_info = {"scan_state": scan.state_string()}
-            state_info["sample_scan"] = scan.get_sample_state_dict()
-            state_info["moderator_scan"] = scan.get_moderator_state_dict()
+            state_info = {"scan_state": scan.state_string(),
+                          "sample_scan": scan.get_sample_state_dict(),
+                          "moderator_scan": scan.get_moderator_state_dict()}
 
             scan_states.append(state_info)
 
-        overview = {"guide_names": guide_names,
+        overview = {"guide_bot_version": __version__,
+                    "guide_names": guide_names,
                     "sample": sample,
                     "moderator": moderator,
                     "analysis_moderators": analysis_moderators,
@@ -631,8 +638,3 @@ class Project:
 
         os.chdir(self.original_wd)
 
-
-
-
-
-
