@@ -12,9 +12,6 @@ from mcstasscript.interface import instr, plotter, functions
 
 class RunFromFile:
     """
-
-
-
     Manages process of combining a user defined Guide object with the
     provided figure of merit and source, create the instrument object and
     perform the numerical optimization. The length system is used to
@@ -54,10 +51,12 @@ class RunFromFile:
         print("debug print")
         print(instr_parameters)
 
+        self.guide.write_log_file(self.scan_name + ".guide_log")
+
         foldername = self.scan_name + "_optimization"
         self.create_folder(foldername)
         self.settings["foldername"] = os.path.join(foldername, "data")
-        best_x = optimizer.run_optimizer(instrument, instr_parameters, self.settings)
+        best_x = optimizer.run_optimizer(instrument, instr_parameters, self.settings, self.scan_name)
         instr_parameters.set_values(best_x)
 
         # optimized_parameters = instr_parameters.extract_instrument_parameters(best_x)
@@ -135,7 +134,7 @@ class RunFromFile:
         self.create_folder(foldername)
         self.settings["foldername"] = os.path.join(foldername, "optimization")
 
-        best_x_analysis = optimizer.run_optimizer(instrument, partial_instr_parameter, self.settings)
+        best_x_analysis = optimizer.run_optimizer(instrument, partial_instr_parameter, self.settings, self.scan_name)
         partial_instr_parameter.set_values(best_x_analysis)
         #analysis_parameters = partial_instr_parameter.extract_instrument_parameters(best_x_analysis)
 
