@@ -1,6 +1,7 @@
 import os
-import pyswarm
+import time
 
+import pyswarm
 import numpy as np
 
 from guide_bot.parameters.instrument_parameters import FreeInstrumentParameter
@@ -12,6 +13,7 @@ from guide_bot.logging import guide_log
 
 from mcstasscript.interface import instr, functions, plotter
 
+
 def optimizer_func(optimizer_x, *args, **kwargs):
     """
     Optimizer function for swarm algorithm, calculates fom with simulation
@@ -43,6 +45,8 @@ def optimizer_func(optimizer_x, *args, **kwargs):
     settings : dict
         Dictionary with settings, ncount and optimized monitor
     """
+    t_start = time.time()
+
     instrument = kwargs["instrument"]
     instr_parameters = kwargs["instrument_parameters"]
     settings = kwargs["settings"]
@@ -58,7 +62,8 @@ def optimizer_func(optimizer_x, *args, **kwargs):
     if len(constraint_values) > 0 and np.min(constraint_values) < 0.0:
         print(" -- Returned 0 for fom due to unfulfilled constraints! -- ")
         if settings["logfile"]:
-            logfile.write_parameter_line(0.0, instr_parameter_input)
+            t_end = time.time()
+            logfile.write_parameter_line(0.0, t_start, t_end, instr_parameter_input)
         return 0.0
 
     if not settings["logfile"]:
@@ -75,13 +80,14 @@ def optimizer_func(optimizer_x, *args, **kwargs):
     fom = -np.sum(np.sum(optimizer_data.Intensity))
     print("  fom =", fom)
 
-    if settings["logfile"]:
-        logfile.write_parameter_line(fom, instr_parameter_input)
-
     if not isinstance(fom, float):
         print("Warning! FOM not a float!")
     
     kwargs["history"].add_run_info(optimizer_x, fom)
+
+    if settings["logfile"]:
+        t_end = time.time()
+        logfile.write_parameter_line(fom, t_start, t_end, instr_parameter_input)
     
     return fom
 
