@@ -307,15 +307,15 @@ class Interval:
         Returns a list of legal intervals, length will be either 1 or 2
         """
         # Interval covers entire allowed interval, nothing left
-        if cut.start < self.start and cut.end > self.end:
+        if cut.start <= self.start and cut.end >= self.end:
             return []
 
         # Interval cuts from start and shortens the interval
-        if cut.start < self.start < cut.end:
+        if cut.start <= self.start < cut.end:
             return [Interval(cut.end, self.end)]
 
         # Interval cuts from end and shortens the interval
-        if cut.start < self.end < cut.end:
+        if cut.start < self.end <= cut.end:
             return [Interval(self.start, cut.start)]
 
         # Interval cuts in the middle and cuts it into two
@@ -438,7 +438,6 @@ class RelativeFreeInstrumentParameter(FreeInstrumentParameter):
         for dependent in make_list(dependent_on):
             self.all_dependent_on.add(dependent.name)
 
-
         self.dynamic_lower.append(limit_function(dependent_on, function, constants))
 
     def add_upper_dynamic(self, dependent_on, function, constants=[]):
