@@ -149,12 +149,10 @@ class Sample:
 
     def add_to_instrument(self, instrument, instrument_parameters):
         """
-        Adds a monitor to the McStas instrument file
+        Adds a figure of merit monitor to the McStas instrument file
 
-        Here adds just a simple PSD_monitor, not even considering
-        the divergence limits yet. Need to return the wavelength range used so
-        it can be passed on to the Source class that will insert the McStas
-        source component.
+        Adds a monitor that will measure the figure of merit. The method
+        returns the wavelength range.
 
         Parameters
         ----------
@@ -165,6 +163,10 @@ class Sample:
         instrument_parameters : InstrumentParameterContainer
             Parameter container where parameters can be added for optimization
         """
+
+        instrument_parameters.add_parameter(ipars.FixedInstrumentParameter("sample_width", self["width"]))
+        instrument_parameters.add_parameter(ipars.FixedInstrumentParameter("sample_height", self["height"]))
+
         mon = instrument.add_component("mon", "Divergence_monitor")
 
         mon.nh = 20
@@ -172,8 +174,8 @@ class Sample:
         mon.filename = '"fom.dat"'
         mon.maxdiv_h = self["div_horizontal"]
         mon.maxdiv_v = self["div_vertical"]
-        mon.xwidth = self["width"]
-        mon.yheight = self["height"]
+        mon.xwidth = "sample_width"
+        mon.yheight = "sample_height"
         mon.restore_neutron = 1
         mon.set_AT([0, 0, "sample_cp"], RELATIVE="Origin")
 
@@ -200,7 +202,6 @@ class Sample:
         width = self["width"] + 2 * math.tan(self["div_horizontal"] * math.pi / 180.0) * self["sample_guide_distance"]
         height = self["height"] + 2 * math.tan(self["div_vertical"] * math.pi / 180.0) * self["sample_guide_distance"]
 
-
         if self["calculate_guide_end_dimensions"]:
             # If end dimensions should be calculated, use exact values
             width_input = width
@@ -235,8 +236,8 @@ class Sample:
         mon = instrument.add_component("psd_lin_horizontal", "PSDlin_monitor")
         mon.nx = 300
         mon.filename = '"psd_lin_horizontal.dat"'
-        mon.xwidth = 2*self["width"]
-        mon.yheight = self["height"]
+        mon.xwidth = 2*"sample_width"
+        mon.yheight = "sample_height"
         mon.restore_neutron = 1
         mon.set_AT([0, 0, "sample_cp"], RELATIVE="Origin")
 
@@ -247,8 +248,8 @@ class Sample:
         mon = instrument.add_component("psd_lin_vertical", "PSDlin_monitor")
         mon.nx = 300
         mon.filename = '"psd_lin_vertical.dat"'
-        mon.xwidth = 2*self["height"]
-        mon.yheight = self["width"]
+        mon.xwidth = 2*"sample_height"
+        mon.yheight = "sample_width"
         mon.restore_neutron = 1
         mon.set_AT([0, 0, 1E-6], RELATIVE="PREVIOUS")
         mon.set_ROTATED([0, 0, 90], RELATIVE="psd_lin_horizontal")
@@ -261,8 +262,8 @@ class Sample:
         mon.nh = 200
         mon.filename = '"divergence_horizontal.dat"'
         mon.h_maxdiv = 2*self["div_horizontal"]
-        mon.xwidth = self["width"]
-        mon.yheight = self["height"]
+        mon.xwidth = "sample_width"
+        mon.yheight = "sample_height"
         mon.restore_neutron = 1
         mon.set_AT([0, 0, 1E-6], RELATIVE="PREVIOUS")
         mon.set_ROTATED([0, 0, 0], RELATIVE="psd_lin_horizontal")
@@ -274,8 +275,8 @@ class Sample:
         mon.nh = 200
         mon.filename = '"divergence_vertical.dat"'
         mon.h_maxdiv = 2*self["div_vertical"]
-        mon.xwidth = self["height"]
-        mon.yheight = self["width"]
+        mon.xwidth = "sample_height"
+        mon.yheight = "sample_width"
         mon.restore_neutron = 1
         mon.set_AT([0, 0, 1E-6], RELATIVE="PREVIOUS")
         mon.set_ROTATED([0, 0, 90], RELATIVE="psd_lin_horizontal")
@@ -287,8 +288,8 @@ class Sample:
         mon.nx = 300
         mon.ny = 300
         mon.filename = '"psd_large.dat"'
-        mon.xwidth = 2*self["width"]
-        mon.yheight = 2*self["height"]
+        mon.xwidth = 2*"sample_width"
+        mon.yheight = 2*"sample_height"
         mon.restore_neutron = 1
         mon.set_AT([0, 0, 1E-6], RELATIVE="PREVIOUS")
         mon.set_ROTATED([0, 0, 0], RELATIVE="psd_lin_horizontal")
@@ -303,8 +304,8 @@ class Sample:
         mon.filename = '"divergence_2D.dat"'
         mon.maxdiv_h = 2*self["div_horizontal"]
         mon.maxdiv_v = 2*self["div_vertical"]
-        mon.xwidth = self["width"]
-        mon.yheight = self["height"]
+        mon.xwidth = "sample_width"
+        mon.yheight = "sample_height"
         mon.restore_neutron = 1
         mon.set_AT([0, 0, 1E-6], RELATIVE="PREVIOUS")
         mon.set_ROTATED([0, 0, 0], RELATIVE="psd_lin_horizontal")
@@ -318,8 +319,8 @@ class Sample:
         mon.Lmax = "max_wavelength"
         mon.nL = 200
         mon.filename = '"wavelength.dat"'
-        mon.xwidth = self["width"]
-        mon.yheight = self["height"]
+        mon.xwidth = "sample_width"
+        mon.yheight = "sample_height"
         mon.restore_neutron = 1
         mon.set_AT([0, 0, 1E-6], RELATIVE="PREVIOUS")
         mon.set_ROTATED([0, 0, 0], RELATIVE="psd_lin_horizontal")
@@ -332,8 +333,8 @@ class Sample:
         mon.ndiv = 200
         mon.filename = '"Acceptance_horizontal.dat"'
         mon.maxdiv_h = 2*self["div_horizontal"]
-        mon.xwidth = 2*self["width"]
-        mon.yheight = self["height"]
+        mon.xwidth = 2*"sample_width"
+        mon.yheight = "sample_height"
         mon.restore_neutron = 1
         mon.set_AT([0, 0, 1E-6], RELATIVE="PREVIOUS")
         mon.set_ROTATED([0, 0, 0], RELATIVE="psd_lin_horizontal")
@@ -348,8 +349,8 @@ class Sample:
         mon.ndiv = 200
         mon.filename = '"Acceptance_vertical.dat"'
         mon.maxdiv_h = 2 * self["div_vertical"]
-        mon.xwidth = 2 * self["height"]
-        mon.yheight = self["width"]
+        mon.xwidth = 2 * "sample_height"
+        mon.yheight = "sample_width"
         mon.restore_neutron = 1
         mon.set_AT([0, 0, 1E-6], RELATIVE="PREVIOUS")
         mon.set_ROTATED([0, 0, 90], RELATIVE="psd_lin_horizontal")
@@ -363,8 +364,8 @@ class Sample:
         mon.nx = 300
         mon.ny = 300
         mon.filename = '"psd.dat"'
-        mon.xwidth = self["width"]
-        mon.yheight = self["height"]
+        mon.xwidth = "sample_width"
+        mon.yheight = "sample_height"
         mon.restore_neutron = 1
         mon.set_AT([0, 0, 1E-6], RELATIVE="PREVIOUS")
         mon.set_ROTATED([0, 0, 0], RELATIVE="psd_lin_horizontal")
@@ -379,8 +380,8 @@ class Sample:
         mon.filename = '"divergence_2D_fom.dat"'
         mon.maxdiv_h = self["div_horizontal"]
         mon.maxdiv_v = self["div_vertical"]
-        mon.xwidth = self["width"]
-        mon.yheight = self["height"]
+        mon.xwidth = "sample_width"
+        mon.yheight = "sample_height"
         mon.restore_neutron = 1
         mon.set_AT([0, 0, 1E-6], RELATIVE="PREVIOUS")
         mon.set_ROTATED([0, 0, 0], RELATIVE="psd_lin_horizontal")
@@ -440,8 +441,8 @@ class Sample:
         mon = instrument.add_component("psd_lin_horizontal_brill", "PSDlin_monitor")
         mon.nx = 300
         mon.filename = '"psd_lin_horizontal_brill.dat"'
-        mon.xwidth = 2 * self["width"]
-        mon.yheight = self["height"]
+        mon.xwidth = 2 * "sample_width"
+        mon.yheight = "sample_height"
         mon.restore_neutron = 1
         mon.set_AT([0, 0, 1E-6], RELATIVE="PREVIOUS")
         mon.set_WHEN("inside_div == 1")
@@ -454,8 +455,8 @@ class Sample:
         mon = instrument.add_component("psd_lin_vertical_brill", "PSDlin_monitor")
         mon.nx = 300
         mon.filename = '"psd_lin_vertical_brill.dat"'
-        mon.xwidth = 2 * self["height"]
-        mon.yheight = self["width"]
+        mon.xwidth = 2 * "sample_height"
+        mon.yheight = "sample_width"
         mon.restore_neutron = 1
         mon.set_AT([0, 0, 1E-6], RELATIVE="PREVIOUS")
         mon.set_ROTATED([0, 0, 90], RELATIVE="psd_lin_horizontal_brill")
@@ -470,8 +471,8 @@ class Sample:
         mon.nh = 200
         mon.filename = '"divergence_horizontal_brill.dat"'
         mon.h_maxdiv = 2 * self["div_horizontal"]
-        mon.xwidth = self["width"]
-        mon.yheight = self["height"]
+        mon.xwidth = "sample_width"
+        mon.yheight = "sample_height"
         mon.restore_neutron = 1
         mon.set_AT([0, 0, 1E-6], RELATIVE="PREVIOUS")
         mon.set_ROTATED([0, 0, 0], RELATIVE="psd_lin_horizontal_brill")
@@ -485,8 +486,8 @@ class Sample:
         mon.nh = 200
         mon.filename = '"divergence_vertical_brill.dat"'
         mon.h_maxdiv = 2 * self["div_vertical"]
-        mon.xwidth = self["height"]
-        mon.yheight = self["width"]
+        mon.xwidth = "sample_height"
+        mon.yheight = "sample_width"
         mon.restore_neutron = 1
         mon.set_AT([0, 0, 1E-6], RELATIVE="PREVIOUS")
         mon.set_ROTATED([0, 0, 90], RELATIVE="psd_lin_horizontal_brill")
@@ -501,8 +502,8 @@ class Sample:
         mon.Lmax = "max_wavelength"
         mon.nL = 200
         mon.filename = '"wavelength_brill.dat"'
-        mon.xwidth = self["width"]
-        mon.yheight = self["height"]
+        mon.xwidth = "sample_width"
+        mon.yheight = "sample_height"
         mon.restore_neutron = 1
         mon.set_AT([0, 0, 1E-6], RELATIVE="PREVIOUS")
         mon.set_ROTATED([0, 0, 0], RELATIVE="psd_lin_horizontal_brill")
