@@ -335,9 +335,9 @@ class BaseSource:
         # Grab the first element of the guide to see what the user specified in terms of start distance
         first_element = guide.guide_elements[0]
         first_element_sp = first_element.start_point
-        if isinstance(first_element_sp, ipars.FreeInstrumentParameter):
-            given_min_start = first_element_sp.get_lower_bound()
-            given_max_start = first_element_sp.get_upper_bound()
+        if isinstance(first_element_sp, ipars.RelativeFreeInstrumentParameter):
+            given_min_start = first_element_sp.get_lower_static_bound()
+            given_max_start = first_element_sp.get_upper_static_bound()
             if given_min_start is None and given_max_start is None:
                 # This is the default value, so the user did not specify start_point
                 if fixed_start_from_source:
@@ -349,10 +349,10 @@ class BaseSource:
                 # The user specified something, check if any information is lacking
                 if given_min_start is None:
                     # A minimum is missing, use minimum from source
-                    first_element_sp.lower_bound = self["min_guide_start"]
+                    first_element_sp.static_lower = self["min_guide_start"]
                 if given_max_start is None:
                     # A maximum is missing, use maximum from source
-                    first_element_sp.lower_bound = self["max_guide_start"]
+                    first_element_sp.static_upper = self["max_guide_start"]
 
     def add_start(self, guide, instrument_parameters):
         """
