@@ -308,3 +308,54 @@ class TestInstrumentParameters(unittest.TestCase):
         relative.clear()
         self.assertEqual(relative.get_value(), None)
 
+    def test_RelativeFreeInstrumentParameter_dynamic_illegal_interval_elliptic_limit(self):
+        """
+        Ensures illegal intervals can be defined with dynamic limits in edge case
+
+        Plotting available to ensure it is working correctly.
+        """
+        minor = RelativeFreeInstrumentParameter("minor_axis", -0.3, 0.1)
+        dim = RelativeFreeInstrumentParameter("start_dimension", 0.0, 0.1)
+
+        minor.add_dynamic_illegal_interval(dim, lambda x: -x, lambda x: x)
+
+        self.assertEqual(len(minor.illegal_dynamic_intervals), 1)
+
+        """
+        minor.set_value(0.8)
+        self.assertEqual(minor.get_value(), 9*0.8 + 5.0 - 3.0)
+
+        dim.set_value(5.0)
+        minor.set_value(0.25)
+        self.assertEqual(minor.get_value(), 9 * 0.25 + 1)
+
+        minor.set_value(0.8)
+        self.assertEqual(minor.get_value(), 9 * 0.8 + 6.0 - 4.0)
+        
+        dim.set_value(1.0)
+
+        n_points = 1000
+        x_values = np.linspace(0.0, 1.0, n_points)
+        y_values = np.zeros((n_points))
+
+        for index in range(len(x_values)):
+            minor.set_value(x_values[index])
+            y_values[index] = minor.get_value()
+
+        plt.scatter(x_values, y_values)
+        plt.show()
+        """
+
+        minor.clear()
+        self.assertEqual(minor.get_value(), None)
+
+        dim.set_value(1.0)  # corresponds to 0.1 (coinciding with limit)
+
+        minor.set_value(0.0)
+        self.assertEqual(minor.get_value(), -0.3)
+
+        minor.set_value(1.0)
+        self.assertEqual(minor.get_value(), -0.1)
+
+        minor.set_value(0.5)
+        self.assertEqual(minor.get_value(), -0.2)
\ No newline at end of file
